==> kie-wb-common-library-backend-7.2.0.Final-sources.jar: org/kie/workbench/common/screens/impl/LibraryAssetTypeDefinition.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.workbench.common.screens.impl;

import javax.enterprise.context.ApplicationScoped;

import org.uberfire.backend.server.util.Paths;
import org.uberfire.backend.vfs.Path;
import org.uberfire.java.nio.file.Files;
import org.uberfire.workbench.type.ResourceTypeDefinition;

@ApplicationScoped
public class LibraryAssetTypeDefinition
        implements ResourceTypeDefinition {

    @Override
    public String getShortName() {
        return "Library assets";
    }

    @Override
    public String getDescription() {
        return "Library assets";
    }

    @Override
    public String getPrefix() {
        return "";
    }

    @Override
    public String getSuffix() {
        return "";
    }

    @Override
    public int getPriority() {
        return 0;
    }

    @Override
    public String getSimpleWildcardPattern() {
        return "*." + getSuffix();
    }

    @Override
    public boolean accept(final Path path) {
        return !(isFolder(path) || path.getFileName().startsWith("."));
    }

    boolean isFolder(final Path path) {
        return Files.isDirectory(Paths.convert(path));
    }
}

==> kie-wb-common-library-backend-7.7.0.Final-sources.jar: org/kie/workbench/common/screens/impl/LibraryAssetTypeDefinition.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.workbench.common.screens.impl;

import javax.enterprise.context.ApplicationScoped;
import javax.inject.Inject;

import org.uberfire.backend.server.util.Paths;
import org.uberfire.backend.vfs.Path;
import org.uberfire.java.nio.file.Files;
import org.uberfire.workbench.category.Category;
import org.uberfire.workbench.category.Others;
import org.uberfire.workbench.type.ResourceTypeDefinition;

@ApplicationScoped
public class LibraryAssetTypeDefinition
        implements ResourceTypeDefinition {

    private Category category;

    public LibraryAssetTypeDefinition() {
    }

    @Inject
    public LibraryAssetTypeDefinition(final Others category) {
        this.category = category;
    }

    @Override
    public Category getCategory() {
        return this.category;
    }

    @Override
    public String getShortName() {
        return "Library assets";
    }

    @Override
    public String getDescription() {
        return "Library assets";
    }

    @Override
    public String getPrefix() {
        return "";
    }

    @Override
    public String getSuffix() {
        return "";
    }

    @Override
    public int getPriority() {
        return 0;
    }

    @Override
    public String getSimpleWildcardPattern() {
        return "*." + getSuffix();
    }

    @Override
    public boolean accept(final Path path) {
        return !(isFolder(path) || path.getFileName().startsWith("."));
    }

    boolean isFolder(final Path path) {
        return Files.isDirectory(Paths.convert(path));
    }
}
